@@ -22,19 +22,20 @@ __all__ = ['cloud_rain',
     'temperature',
     'uamiv',
     'vertical_diffusivity',
-    'wind']
+    'wind',
+    'lateral_boundary']
     
-from cloud_rain.Memmap import cloud_rain
-from height_pressure.Memmap import height_pressure
-from humidity.Memmap import humidity
-from finst.Memmap import finst
-from ipr.Memmap import ipr
-from irr.Memmap import irr
-from landuse.Memmap import landuse
-from lateral_boundary.Memmap import lateral_boundary
-from one3d.Memmap import one3d
-from point_source.Memmap import point_source
-from temperature.Memmap import temperature
-from uamiv.Memmap import uamiv
-from vertical_diffusivity.Memmap import vertical_diffusivity
-from wind.Memmap import wind
+from .uamiv.Memmap import uamiv
+from .cloud_rain.Memmap import cloud_rain
+from .height_pressure.Memmap import height_pressure
+from .humidity.Memmap import humidity
+from .finst.Memmap import finst
+from .ipr.Memmap import ipr
+from .irr.Memmap import irr
+from .landuse.Memmap import landuse
+from .lateral_boundary.Memmap import lateral_boundary
+from .point_source.Memmap import point_source
+from .temperature.Memmap import temperature
+from .wind.Memmap import wind
+from .vertical_diffusivity.Memmap import vertical_diffusivity
+from .one3d.Memmap import one3d
