@@ -12,5 +12,8 @@ __doc__ = """
 .. moduleauthor:: Barron Henderson <barronh@unc.edu>
 """
 
-from PseudoNetCDF.camxfiles.one3d.Write import ncf2one3d as ncf2hum
+from PseudoNetCDF.camxfiles.one3d.Write import ncf2one3d as ncf2humidity
 
+from PseudoNetCDF._getwriter import registerwriter
+registerwriter('camxfiles.humidity', ncf2humidity)
+registerwriter('humidity', ncf2humidity)
