@@ -11,9 +11,9 @@ __doc__ = """
 """
 __all__=['Memmap','Read','Write']
 
-import Memmap
-import Read
-import Write
+from . import Memmap
+from . import Read
+from . import Write
 
 if __name__ == '__main__':
     from PseudoNetCDF.camxfiles.point_source.Memmap import point_source
