@@ -16,7 +16,7 @@ from numpy import array
 
 from PseudoNetCDF.MetaNetCDF import add_derived, time_avg_new_unit
 from PseudoNetCDF.sci_var import PseudoNetCDFFile, PseudoNetCDFVariables, PseudoNetCDFVariable
-from Memmap import vertical_diffusivity as reg_vertical_diffusivity
+from .Memmap import vertical_diffusivity as reg_vertical_diffusivity
 
 class vertical_diffusivity_center_time(time_avg_new_unit):
     __reader__=reg_vertical_diffusivity
