@@ -12,4 +12,9 @@ __doc__ = """
 .. moduleauthor:: Barron Henderson <barronh@unc.edu>
 """
 
-from PseudoNetCDF.camxfiles.one3d.Write import ncf2one3d as ncf2kv
+from PseudoNetCDF.camxfiles.one3d.Write import ncf2one3d as ncf2vertical_diffusivity
+
+from PseudoNetCDF._getwriter import registerwriter
+registerwriter('camxfiles.vertical_diffusivity', ncf2vertical_diffusivity)    
+registerwriter('vertical_diffusivity', ncf2vertical_diffusivity)    
+
